@@ -1,12 +1,13 @@
 from collections.abc import Callable
+from koala_formatter.formatters import utils
 from koala_formatter.formatters.formatter_base import FormatterBase
 
 
 class OracleFormatter(FormatterBase):
 
     def __init__(self, db_url: str = None):
-        super().__init__(__name__)
-        self._host = self._get_host(db_url)
+        super().__init__()
+        self._host = utils.get_host(db_url)
 
     def __enter__(self):
         return self
@@ -17,7 +18,7 @@ class OracleFormatter(FormatterBase):
 
     @property
     def required_collection_node_fields(self):
-        return tuple(('db_name', 'schema_name', 'table_name', 'table_description', 'team_name'))
+        return 'db_name', 'schema_name', 'table_name', 'table_description', 'team_name'
 
     @property
     def resource_node_type(self):
@@ -25,12 +26,7 @@ class OracleFormatter(FormatterBase):
 
     @property
     def required_resource_node_fields(self):
-        return tuple(('db_name', 'schema_name', 'table_name', 'column_name',
-                      'column_description', 'data_type'))
-
-    @property
-    def required_edge_fields(self):
-        return tuple(('inV', 'outV', 'label'))
+        return 'db_name', 'schema_name', 'table_name', 'column_name', 'column_description', 'data_type'
 
     @property
     def collection_id_creator(self) -> Callable:
@@ -43,6 +39,3 @@ class OracleFormatter(FormatterBase):
     @property
     def origin_host(self):
         return self._host
-
-    def create_nodes(self, tables, columns):
-        return self._create_graph_objects(tables, columns)
