@@ -5,11 +5,12 @@ from koala_formatter.exceptions.exceptions import InvalidGraphObject
 
 class GraphNode(GraphObjectBase):
 
-    def __init__(self, node, node_type, required_fields, id_creator):
+    def __init__(self, node, node_type, required_fields, id_creator, host_name):
         super().__init__(obj=node, required_fields=required_fields)
         self._node = node
         self._node_id = self._create_node_id(id_creator)
         self._node["type"] = node_type
+        self._node["host"] = host_name
 
     def as_json(self) -> MutableMapping:
         """ Returns the Graph node as mapping object
